@@ -14,12 +14,12 @@
   With help of Joe Felsenstein (joe@genetics.washington.edu),
   Mary Kuhner and Jon Yamato (mkkuhner@genetics.washington.edu)
 
-  $Id: definitions.h,v 1.52 2001/04/08 04:24:44 beerli Exp $
+  $Id: definitions.h,v 1.53 2001/04/11 16:53:49 beerli Exp $
 
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "0.9.14"
+#define MIGRATEVERSION "1.0.1"
 #endif
 
 #define MAINTAINER "Peter Beerli <beerli@genetics.washington.edu>"
@@ -35,6 +35,7 @@
 #endif
 
 #ifdef __MWERKS__
+#include "conf.h"
 #undef HAVE_LGAMMA
 #define HAVE_STRFTIME 1
 #define HIGHBITS
@@ -42,9 +43,9 @@
 #ifdef macintosh
 #define MAC
 #include <ansi_prefix.mac.h>	/*fixes time problems */
-#include "unix.mac.h"
 #else /*macintosh */
 #define DOS
+#undef HAVE_STRINGS_H
 #undef HAVE_LGAMMA
 #endif /*windows */
 #endif /*MWERKS*/
@@ -303,6 +304,7 @@ typedef unsigned char boolean;
 #define MAXPOP   100		/*n*(n-1)+n) */
 #define MAXPARAM 10000
 #define HEADER 1
+#define NOHEADER 0
 /* migration histogram material*/
 #define MIGHIST_ELEM 5
 /* stop while loops after some time*/
@@ -319,3 +321,9 @@ typedef unsigned char boolean;
 #include <memdebug.h>
 #endif
 #endif /*definitions */
+
+
+
+
+
+
