@@ -8,7 +8,7 @@
  moved out from world.c                                                                                                               
  Peter Beerli 2000, Seattle
  beerli@genetics.washington.edu
- $Id: lrt.c,v 1.6 2001/04/09 17:59:04 beerli Exp $
+ $Id: lrt.c,v 1.7 2001/04/11 16:53:49 beerli Exp $
 -------------------------------------------------------*/
 #define SICK_VALUE    -1
 #include "migration.h"
@@ -73,6 +73,7 @@ print_lratio_test (world_fmt * world, long *Gmax)
   long c;
   long r, locus;
   long df;
+  int header;
   nr_fmt *nr;
   double *param0;
   double *param1;
@@ -97,19 +98,24 @@ print_lratio_test (world_fmt * world, long *Gmax)
       else
 	create_apg0 (nr->apg0[0][locus], nr, &world->atl[0][locus]);
     }
+  if(world->loci>1)
+    locus=world->loci;
+  else
+    locus=0;
   for(c=0; c<world->options->lratio->counter; c++)
     {
       PAGEFEEDWORLD;
+      header = (c == 0) ? HEADER : NOHEADER;
       if (world->options->lratio->data[c].type == MLE)
 	{
-	  memcpy(param1,world->atl[0][world->loci].param,
+	  memcpy(param1,world->atl[0][locus].param,
 		 sizeof(double)*world->numpop2);
 	  df = set_test_param (param0, 
 			       world->options->lratio->data[c].value1, 
 			       world, 0, -1, maxwhich, &maxnum);
 	  test_loci_like (nr, param0, param1,
 			  df, world->loci, world, maxwhich, 
-			  maxnum, HEADER, 
+			  maxnum, header, 
 			  world->options->lratio->data[c].value1,
 			  NULL);
 	}
