@@ -30,7 +30,9 @@
 #include <signal.h>
 #include <stdarg.h>
 #include "migration.h"
-
+#ifdef MPI
+#include "migrate_mpi.h"
+#endif
 
 #ifdef DMALLOC_FUNC_CHECK
 #include <dmalloc.h>
@@ -89,49 +91,38 @@ signalhandler (int sig)
 #ifndef __MWERKS__
     case SIGIOT:
       fprintf (stderr, "\nSEVERE ERROR: Input/Output problem!\n");
-      fprintf (stderr,
-	       "              Most likely a fatal error in the infile or parmfile\n\n");
-      fprintf (stderr,
-	       "              Please report error with as much detail as possible to\n");
+      fprintf (stderr, "              Most likely a fatal error in the infile or parmfile\n\n");
+      fprintf (stderr, "              Please report error with as much detail as possible to\n");
       fprintf (stderr, "              %s\n\n", MAINTAINER);
       exit (sig);
       break;
     case SIGTRAP:
       fprintf (stderr, "SEVERE ERROR: Trace trap\n");
-      fprintf (stderr,
-	       "              there was an an overflow/underflow/0 divide problem\n");
+      fprintf (stderr, "              there was an an overflow/underflow/0 divide problem\n");
       fprintf (stderr, "              or some other problems.\n");
-      fprintf (stderr,
-	       "              But check your infile for errors, too.\n");
-      fprintf (stderr,
-	       "              Please report error with as much detail as possible to\n");
+      fprintf (stderr, "              But check your infile for errors, too.\n");
+      fprintf (stderr, "              Please report error with as much detail as possible to\n");
       fprintf (stderr, "              %s\n\n", MAINTAINER);
       exit (sig);
       break;
     case SIGBUS:
       fprintf (stderr, "SEVERE ERROR: Bus problems\n");
-      fprintf (stderr,
-	       "              this results in an non recoverable crash\n");
-      fprintf (stderr,
-	       "              But check your infile for errors, too.\n");
-      fprintf (stderr,
-	       "              Please report error with as much detail as possible to\n");
+      fprintf (stderr, "              this results in an non recoverable crash\n");
+      fprintf (stderr, "              But check your infile for errors, too.\n");
+      fprintf (stderr, "              Please report error with as much detail as possible to\n");
       fprintf (stderr, "              %s\n\n", MAINTAINER);
       exit (sig);
       break;
     case SIGXCPU:
       fprintf (stderr, "SEVERE ERROR: This program has a time limit?\n");
       fprintf (stderr, "              We didn' program in a time limit,\n");
-      fprintf (stderr,
-	       "              report this error to your system administrator, please.\n");
+      fprintf (stderr, "              report this error to your system administrator, please.\n");
       exit (sig);
       break;
     case SIGXFSZ:
       fprintf (stderr, "SEVERE ERROR: This program has a file size limit?\n");
-      fprintf (stderr,
-	       "              We didn't program in a file size limit,\n");
-      fprintf (stderr,
-	       "              report this error to your system administrator, please.\n");
+      fprintf (stderr, "              We didn't program in a file size limit,\n");
+      fprintf (stderr, "              report this error to your system administrator, please.\n");
       exit (sig);
       break;
     case SIGUSR1:
@@ -141,35 +132,30 @@ signalhandler (int sig)
 #endif
     case SIGFPE:
       fprintf (stderr, "SEVERE ERROR: Floating point exception\n");
-      fprintf (stderr,
-	       "              There was an integer/floating point problem\n");
-      fprintf (stderr,
-	       "              Often this is a division by zero. If you dataset is moderately sized\n");
-      fprintf (stderr,
-	       "              this is most likely an error in you data (infile).\n");
-      fprintf (stderr,
-	       "              Please report error with as much detail as possible to\n");
+      fprintf (stderr, "              There was an integer/floating point problem\n");
+      fprintf (stderr, "              Often this is a division by zero. If you dataset is moderately sized\n");
+      fprintf (stderr, "              this is most likely an error in you data (infile).\n");
+      fprintf (stderr, "              Please report error with as much detail as possible to\n");
       fprintf (stderr, "              %s\n\n", MAINTAINER);
       exit (sig);
       break;
     case SIGSEGV:
+#ifdef MPI
+      fprintf (stderr, "SEVERE ERROR: Segmentation fault on Node **%i**\n",myID);
+#else
       fprintf (stderr, "SEVERE ERROR: Segmentation fault\n");
-      fprintf (stderr,
-	       "              this results in an non recoverable crash\n");
-      fprintf (stderr,
-	       "              But check the datatype and your infile afor errors, too.\n");
-      fprintf (stderr,
-	       "              Please report error with as much detail as possible to\n");
+#endif
+      fprintf (stderr, "              this results in an non recoverable crash.\n");
+      fprintf (stderr, "              But check the datatype and your infile for errors, too.\n");
+      fprintf (stderr, "              Please report error with as much detail as possible to\n");
       fprintf (stderr, "              %s\n\n", MAINTAINER);
       exit (sig);
       break;
     case SIGILL:
       fprintf (stderr, "SEVERE ERROR: Illegal instruction!\n");
       fprintf (stderr, "              this is maybe a programming error.\n");
-      fprintf (stderr,
-	       "              But check your infile for errors, too.\n");
-      fprintf (stderr,
-	       "              Please report error with as much detail as possible to\n");
+      fprintf (stderr, "              But check your infile for errors, too.\n");
+      fprintf (stderr, "              Please report error with as much detail as possible to\n");
       fprintf (stderr, "              %s\n\n", MAINTAINER);
       exit (sig);
       break;
@@ -237,15 +223,13 @@ malloc_error_found (int value)
       fprintf (stderr, "vm_copy failed\n");
       break;
     case 3:
-      fprintf (stderr,
-	       "I tried to reallocate or free space which was already freed\n");
+      fprintf (stderr, "I tried to reallocate or free space which was already freed\n");
       break;
     case 4:
       fprintf (stderr, "Internal memory verification in heap failed\n");
       break;
     case 5:
-      fprintf (stderr,
-	       "I tried to reallocate or free space which was never allocated\n");
+      fprintf (stderr, "I tried to reallocate or free space which was never allocated\n");
       break;
     default:
       fprintf (stderr, "huh, what malloc error was this?\n");
@@ -271,9 +255,7 @@ LAMARC_malloc (const unsigned long size, const char file[], const long line)
   x = malloc (size);
   if (x == NULL)
     {
-      fprintf (stderr,
-	       "ERROR in memory allocation (malloc(%li)) in file %s on line %li\n",
-	       size, file, line);
+      fprintf (stderr, "ERROR in memory allocation (malloc(%li)) in file %s on line %li\n", size, file, line);
       exit (-1);
     }
   return x;
@@ -281,32 +263,26 @@ LAMARC_malloc (const unsigned long size, const char file[], const long line)
 
 
 void *
-LAMARC_calloc (const unsigned long repeats, const unsigned long size,
-	       const char file[], const long line)
+LAMARC_calloc (const unsigned long repeats, const unsigned long size, const char file[], const long line)
 {
   void *x;
   x = calloc (repeats, size);
   if (x == NULL)
     {
-      fprintf (stderr,
-	       "ERROR in memory allocation (calloc(%li,%li)) in file %s on line %li\n",
-	       repeats, size, file, line);
+      fprintf (stderr, "ERROR in memory allocation (calloc(%li,%li)) in file %s on line %li\n", repeats, size, file, line);
       exit (-1);
     }
   return x;
 }
 
 void *
-LAMARC_realloc (void *ptr, const unsigned long size, const char file[],
-		const long line)
+LAMARC_realloc (void *ptr, const unsigned long size, const char file[], const long line)
 {
   void *x;
   x = realloc (ptr, size);
   if (x == NULL)
     {
-      fprintf (stderr,
-	       "ERROR in memory allocation (realloc(ptr,%li)) in file %s on lin %li\n",
-	       size, file, line);
+      fprintf (stderr, "ERROR in memory allocation (realloc(ptr,%li)) in file %s on lin %li\n", size, file, line);
       exit (-1);
     }
   return x;
