@@ -4,14 +4,13 @@
  Maximum likelihood estimation 
  of migration rate  and effectice population size
  using a Metropolis-Hastings Monte Carlo algorithm                            
- -------------------------------------------------------                        
-H E L P E R     R O U T I N E S 
+ -------------------------------------------------------                       
 
- 
+ H E L P E R     R O U T I N E S 
 
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: tools.h,v 1.8 2000/04/04 18:39:44 beerli Exp $
+ $Id: tools.h,v 1.13 2001/03/09 16:29:19 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -21,16 +20,13 @@ extern node *crawlback (const node * theNode);
 extern node *crawl (node * theNode);
 extern node *showtop (node * theNode);
 extern void adjust_time (node * theNode, double tyme);
-extern void insert_migr_node (world_fmt * world, node * up, node * down,
-			      migr_table_fmt * migr_table,
-			      long *migr_table_counter);
+extern void insert_migr_node (world_fmt * world, node * up, node * down, migr_table_fmt * migr_table, long *migr_table_counter);
 extern void children (node * mother, node ** brother, node ** sister);
 /* math tools */
 extern double incompletegamma (double x, double alpha);
 extern double polygamma (long n, double z);
 extern void invert_matrix (double **a, long nsize);
-extern boolean nrcheck (double **m, double **tm, double *v, long nrows,
-			double *r1, double *r2, boolean do_newton);
+extern boolean nrcheck (double **m, double **tm, double *v, long nrows, double *r1, double *r2, boolean do_newton);
 extern double rannor (double mean, double sd);
 extern double find_chi (long df, double prob);
 extern double probchi (long df, double chi);
@@ -40,20 +36,23 @@ extern void gamma_rates (double *rate, long categs, char *input);
 extern double mylgamma (double z);
 #endif
 extern double sum (double *vector, long n);
-
+extern double logfac(long n);
 
 extern char lowercase (char c);
 extern char uppercase (char c);
 
+/* vector initialization and calc*/
+extern void doublevec1d(double **v, long size);
+extern void doublevec2d(double ***v, long size1, long size2);
+extern void free_doublevec2d(double **v);
+extern void setdoublevec1d(double **v, double *w, long size);
+extern void add_vector(double *result, double *v, long size);
+
 /*filemanipulation */
-extern void init_files (world_fmt * world, data_fmt * data,
-			option_fmt * options);
-extern void exit_files (world_fmt * world, data_fmt * data,
-			option_fmt * options);
-extern void openfile (FILE ** fp, char *filename, char *mode,
-		      const char *application, char *perm);
-extern void read_savesum (world_fmt * world, option_fmt * options,
-			  data_fmt * data);
+extern void init_files (world_fmt * world, data_fmt * data, option_fmt * options);
+extern void exit_files (world_fmt * world, data_fmt * data, option_fmt * options);
+extern void openfile (FILE ** fp, char *filename, char *mode, const char *application, char *perm);
+extern long read_savesum (world_fmt * world, option_fmt * options, data_fmt * data);
 extern void write_savesum (world_fmt * world);
 
 /* string manipulation */
@@ -75,6 +74,11 @@ extern long m2mml2 (long i, long topop, long numpop);
 extern long mmstart (long pop, long numpop);
 extern long mmend (long pop, long numpop);
 extern long mml2m (long pos, long numpop);
-
+extern void print_line (FILE * outfile, char c, long nn, long flag);
+/* reading from char * buffer */
+char sgetc(char **buffer);
+char *sgets(char *s, int size, char **stream);
 
 #endif /*TOOLS_INCLUDE */
+
+
